Package: bcmixed
Type: Package
Title: Mixed Effect Model with the Box-Cox Transformation
Version: 0.1.6
Authors@R: c(person("Kazushi", "Maruo", email = "kazushi.maruo@gmail.com",
                  role = c("aut", "cre")),
                 person("Ryota", "Ishii", role = "aut"),
                 person("Yusuke", "Yamaguchi", role = "ctb"),
                 person("Masahiko", "Gosho", role = "ctb"))
Description: Inference on the marginal model of the mixed effect model with 
    the Box-Cox transformation and on the model median differences between
    treatment groups for longitudinal randomized clinical trials. These 
    statistical methods are proposed by Maruo et al. (2017) 
    <doi:10.1002/sim.7279>.
Depends: R (>= 3.3.3)
Imports: MASS (>= 7.3-45), nlme (>= 3.1-131)
Suggests: testthat (>= 1.0.2)
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-17 15:37:20 UTC; kazus
Author: Kazushi Maruo [aut, cre],
  Ryota Ishii [aut],
  Yusuke Yamaguchi [ctb],
  Masahiko Gosho [ctb]
Maintainer: Kazushi Maruo <kazushi.maruo@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-17 16:20:07 UTC
Built: R 4.5.2; ; 2026-05-17 19:03:56 UTC; unix
