# Generated by roxygen2: do not edit by hand

S3method(boxplot,bcmmrm)
S3method(coef,bcmarg)
S3method(coef,bcmmrm)
S3method(fitted,bcmarg)
S3method(fitted,bcmmrm)
S3method(logLik,bcmarg)
S3method(logLik,bcmmrm)
S3method(plot,bcmmrm)
S3method(predict,bcmarg)
S3method(print,bcmarg)
S3method(print,bcmmrm)
S3method(print,summary.bcmarg)
S3method(print,summary.bcmmrm)
S3method(summary,bcmarg)
S3method(summary,bcmmrm)
S3method(vcov,bcmarg)
S3method(vcov,bcmmrm)
export(bcmarg)
export(bcmmrm)
export(bcreg)
export(bct)
export(bct.v)
importFrom(MASS,ginv)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,boxplot)
importFrom(graphics,grid)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(nlme,corAR1)
importFrom(nlme,corCompSymm)
importFrom(nlme,corMatrix)
importFrom(nlme,corSymm)
importFrom(nlme,gls)
importFrom(nlme,glsControl)
importFrom(nlme,varIdent)
importFrom(stats,coef)
importFrom(stats,ftable)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,optimize)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,sd)
importFrom(stats,xtabs)
